from z3c.form.browser.text import TextWidget
from z3c.form.interfaces import IFieldWidget
from z3c.form.interfaces import ITextWidget
from z3c.form.widget import FieldWidget
from zope.component import adapter
from zope.interface import implementer
from zope.schema.interfaces import IURI

from plone.app.z3cform.interfaces import IPloneFormLayer


class IURIWidget(ITextWidget):
    """ URI Widget """


@implementer(IURIWidget)
class URIWidget(TextWidget):
    klass = u'uri-widget'
    value = None


@adapter(IURI, IPloneFormLayer)
@implementer(IFieldWidget)
def URIFieldWidget(field, request):
    return FieldWidget(field, URIWidget(request))



from zope.i18nmessageid import MessageFactory
_ = MessageFactory('plone')


from .email import Email
from .email import IEmail

from .path import Path
from .path import IPath

# zope.schema convenience imports
from zope.schema._field import ASCII
from zope.schema._field import ASCIILine
from zope.schema._field import Bool
from zope.schema._field import Bytes
from zope.schema._field import BytesLine
from zope.schema._field import Choice
from zope.schema._field import Container
from zope.schema._field import Date
from zope.schema._field import Datetime
from zope.schema._field import Decimal
from zope.schema._field import Dict
from zope.schema._field import DottedName
from zope.schema._field import Field
from zope.schema._field import Float
from zope.schema._field import FrozenSet
from zope.schema._field import Id
from zope.schema._field import Int
from zope.schema._field import InterfaceField
from zope.schema._field import Iterable
from zope.schema._field import List
from zope.schema._field import MinMaxLen
from zope.schema._field import NativeString
from zope.schema._field import NativeStringLine
from zope.schema._field import Object
from zope.schema._field import Orderable
from zope.schema._field import Password
from zope.schema._field import Set
from zope.schema._field import SourceText
from zope.schema._field import Text
from zope.schema._field import TextLine
from zope.schema._field import Time
from zope.schema._field import Timedelta
from zope.schema._field import Tuple
from zope.schema._field import URI



from plone.schema import _
from zope.interface import implementer
from zope.schema import NativeStringLine
from zope.schema.interfaces import IFromUnicode
from zope.schema.interfaces import INativeStringLine
from zope.schema.interfaces import ValidationError
import re

# Taken from http://www.regular-expressions.info/email.html
_isemail = r"[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,4}"
_isemail = re.compile(_isemail).match


class IEmail(INativeStringLine):
    """A field containing an email address
    """


class InvalidEmail(ValidationError):
    __doc__ = _("""The specified email is not valid.""")


@implementer(IEmail, IFromUnicode)
class Email(NativeStringLine):
    """Email schema field
    """

    def _validate(self, value):
        super(Email, self)._validate(value)
        if _isemail(value):
            return

        raise InvalidEmail(value)

    def fromUnicode(self, value):
        v = str(value.strip())
        self.validate(v)
        return v



from zope.interface import implementer
from zope.schema import Choice
from zope.schema.interfaces import IChoice


class IPath(IChoice):
    """A field for selecting the path of an object in the site."""


@implementer(IPath)
class Path(Choice):
    pass



from plone.schema import _
from plone.schema.email import Email, IEmail
from plone.schemaeditor.fields import FieldFactory
from zope.interface import Attribute
from zope.schema import URI
from zope.schema.interfaces import IURI


class IURI(IURI):

    # prevent some settings from being included in the field edit form
    default = Attribute('')


class IEmail(IEmail):

    # prevent some settings from being included in the field edit form
    default = Attribute('')


URIFactory = FieldFactory(URI, _(u'URL'))
EmailFactory = FieldFactory(Email, _(u'Email'))



from setuptools import setup, find_packages

version = '1.0.0'

long_description = open("README.rst").read() + "\n" + \
                   open("CHANGES.rst").read()

setup(
    name='plone.schema',
    version=version,
    description='Plone specific extensions and fields for zope schematas',
    long_description=long_description,
    classifiers=[
        "Framework :: Zope2",
        "Framework :: Plone",
        "Framework :: Plone :: 5.0",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: BSD License",
    ],
    keywords='plone schema',
    author='Plone Foundation',
    author_email='plone-developers@lists.sourceforge.net',
    url='http://plone.org/',
    license='BSD',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['plone'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'plone.app.z3cform',
        'z3c.form',
        'zope.component',
        'zope.i18nmessageid',
        'zope.interface',
        'zope.schema',
    ],
    extras_require={
        'test': ['plone.app.testing'],
    },
)



from zope.component import adapter
from zope.interface import implementer
from z3c.form.interfaces import ITextWidget
from z3c.form.interfaces import IFieldWidget
from z3c.form.browser.text import TextWidget
from z3c.form.widget import FieldWidget

from plone.app.z3cform.interfaces import IPloneFormLayer

from plone.schema.email import IEmail


class IEmailWidget(ITextWidget):
    """ Email Widget """


@implementer(IEmailWidget)
class EmailWidget(TextWidget):
    klass = u'email-widget'
    value = None


@adapter(IEmail, IPloneFormLayer)
@implementer(IFieldWidget)
def EmailFieldWidget(field, request):
    return FieldWidget(field, EmailWidget(request))
